[llvm-commits] CVS: llvm/include/llvm/Analysis/DSNode.h

Chris Lattner lattner at cs.uiuc.edu
Fri Nov 1 18:37:07 PST 2002


Changes in directory llvm/include/llvm/Analysis:

DSNode.h updated: 1.3 -> 1.4

---
Log message:

Implement the "unknown flag" which mainly consists of aligning printing code



---
Diffs of the changes:

Index: llvm/include/llvm/Analysis/DSNode.h
diff -u llvm/include/llvm/Analysis/DSNode.h:1.3 llvm/include/llvm/Analysis/DSNode.h:1.4
--- llvm/include/llvm/Analysis/DSNode.h:1.3	Fri Nov  1 18:11:12 2002
+++ llvm/include/llvm/Analysis/DSNode.h	Fri Nov  1 18:36:03 2002
@@ -61,13 +61,14 @@
   void operator=(const DSNode &); // DO NOT IMPLEMENT
 public:
   enum NodeTy {
-    ShadowNode = 0,        // Nothing is known about this node...
-    AllocaNode = 1 << 0,   // This node was allocated with alloca
-    NewNode    = 1 << 1,   // This node was allocated with malloc
-    GlobalNode = 1 << 2,   // This node was allocated by a global var decl
-    Incomplete = 1 << 3,   // This node may not be complete
-    Modified   = 1 << 4,   // This node is modified in this context
-    Read       = 1 << 5,   // This node is read in this context
+    ShadowNode  = 0,        // Nothing is known about this node...
+    AllocaNode  = 1 << 0,   // This node was allocated with alloca
+    NewNode     = 1 << 1,   // This node was allocated with malloc
+    GlobalNode  = 1 << 2,   // This node was allocated by a global var decl
+    UnknownNode = 1 << 3,   // This node points to unknown allocated memory 
+    Incomplete  = 1 << 4,   // This node may not be complete
+    Modified    = 1 << 5,   // This node is modified in this context
+    Read        = 1 << 6,   // This node is read in this context
   };
   
   /// NodeType - A union of the above bits.  "Shadow" nodes do not add any flags





More information about the llvm-commits mailing list